aboutsummaryrefslogtreecommitdiffstats
path: root/src/java/com/jogamp/gluegen/GlueEmitter.java
diff options
context:
space:
mode:
Diffstat (limited to 'src/java/com/jogamp/gluegen/GlueEmitter.java')
-rw-r--r--src/java/com/jogamp/gluegen/GlueEmitter.java7
1 files changed, 4 insertions, 3 deletions
diff --git a/src/java/com/jogamp/gluegen/GlueEmitter.java b/src/java/com/jogamp/gluegen/GlueEmitter.java
index bb46cf5..0e8d61f 100644
--- a/src/java/com/jogamp/gluegen/GlueEmitter.java
+++ b/src/java/com/jogamp/gluegen/GlueEmitter.java
@@ -50,6 +50,7 @@ import com.jogamp.gluegen.cgram.types.*;
public interface GlueEmitter {
public void readConfigurationFile(String filename) throws Exception;
+ public JavaConfiguration getConfiguration();
/**
* Begin the emission of glue code. This might include opening files,
@@ -91,11 +92,11 @@ public interface GlueEmitter {
public void beginStructs(TypeDictionary typedefDictionary,
TypeDictionary structDictionary,
Map<Type, Type> canonMap) throws Exception;
/** Emit glue code for the given CompoundType. alternateName is
provided when the CompoundType (e.g. "struct foo_t") has not
been typedefed to anything but the type of "pointer to struct
foo_t" has (e.g. "typedef struct foo_t {} *Foo"); in this case
- alternateName would be set to Foo. */
- public void emitStruct(CompoundType t, String alternateName) throws Exception;
+ typedefType would be set to pointer type Foo. */
+ public void emitStruct(CompoundType t, Type typedefType) throws Exception;
public void endStructs() throws Exception;
}
@@ -91,11 +92,11 @@ public interface GlueEmitter {
TypeDictionary structDictionary,
Map<Type, Type> canonMap) throws Exception;
- /** Emit glue code for the given CompoundType. alternateName is
+ /** Emit glue code for the given CompoundType. typedefType is
provided when the CompoundType (e.g. "struct foo_t") has not
been typedefed to anything but the type of "pointer to struct